@@ -1,5 +1,5 @@
 package DBIx::Perlish::Parse;
-# $Id: Parse.pm,v 1.91 2008/10/16 08:18:01 tobez Exp $
+# $Id: Parse.pm,v 1.92 2008/11/08 17:31:35 tobez Exp $
 use 5.008;
 use warnings;
 use strict;
@@ -243,6 +243,9 @@ sub get_value
 	} elsif (is_svop($op, "gvsv") || is_padop($op, "gvsv")) {
 		my $gv = get_gv($S, $op, bailout => 1);
 		$val = ${$gv->SV->object_2svref};
+	} elsif (is_unop($op, "null") && (is_svop($op->first, "gvsv") || is_padop($op->first, "gvsv"))) {
+		my $gv = get_gv($S, $op->first, bailout => 1);
+		$val = ${$gv->SV->object_2svref};
 	} else {
 		return () if $p{soft};
 		bailout $S, "cannot parse \"", $op->name, "\" op as a value or value reference";
@@ -383,16 +386,21 @@ sub try_parse_attr_assignment
 	$op = $op->sibling;
 	my $attr = is_const($S, $op);
 	return unless $attr;
+	my @attr = grep { length($_) } split /(?:[\(\)])/, $attr;
+	return unless @attr;
 	$op = $op->sibling;
 	return unless is_svop($op, "method_named");
 	return unless want_method($S, $op, "import");
 	if ($realname) {
-		if (lc $attr eq "table") {
-			$attr = $realname;
+		if (lc $attr[0] eq "table") {
+			@attr = ($realname);
 		} else {
-			bailout $S, "cannot decide whether you refer to $realname table or to $attr table";
+			bailout $S, "cannot decide whether you refer to $realname table or to @attr table";
 		}
+	} else {
+		shift @attr if lc $attr[0] eq "table" && @attr > 1;
 	}
+	$attr = join ".", @attr;
 	new_var($S, $varn, $attr);
 	return $attr;
 }
@@ -777,6 +785,10 @@ sub parse_assign
 			my $tab = try_parse_attr_assignment($S,
 				$op->last->first->sibling, $val);
 			return if $tab;
+		} elsif ($val = is_const($S, $op->first)) {
+			my $tab = try_parse_attr_assignment($S,
+				$op->last->first->sibling, $val);
+			return if $tab;
 		} elsif (my $codeop = try_get_dbfetch($S, $op->first)) {
 			my $sql = handle_subselect($S, $codeop, returns_dont_care => 1);
 			my $tab = try_parse_attr_assignment($S,
